@@ -1,7 +1,10 @@
 from sqlalchemy import text
 
 
-def sql(query, db):
+def sql(query):
+    app = WeDeliverCore.get_app()
+    db = app.extensions['sqlalchemy'].db
+
     result = db.engine.execute(text(query))
     result_list = list()
     # app.logger.debug(result)
